Sources
=======
BioGRID
-------
.. automodule:: bio2bel.sources.biogrid
    :members:

IntAct
------
.. automodule:: bio2bel.sources.intact
    :members:

Protein Interactions Database (PID)
-----------------------------------
.. automodule:: bio2bel.sources.pid
    :members:

TFRegulons
----------
.. automodule:: bio2bel.sources.tfregulons
    :members:
